@@ -8,8 +8,7 @@ try:
     from django.apps import AppConfig
 
     class Config(AppConfig):
-        label = 'fobi.contrib.plugins.form_elements.fields.text'
-        name = 'fobi.contrib.plugins.form_elements.fields.text'
+        name = label = 'fobi.contrib.plugins.form_elements.fields.text'
 
 except ImportError:
     pass
