@@ -8,7 +8,10 @@ from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
 
-from fobi.contrib.plugins.form_handlers.db_store.models import SavedFormDataEntry
+from fobi.contrib.plugins.form_handlers.db_store.models import (
+    SavedFormDataEntry
+)
+from fobi.contrib.plugins.form_handlers.db_store.helpers import DataExporter
 
 class SavedFormDataEntryAdmin(admin.ModelAdmin):
     """
@@ -30,6 +33,8 @@ class SavedFormDataEntryAdmin(admin.ModelAdmin):
         }),
     )
 
+    actions = ['export_data']
+
     class Meta:
         app_label = _('Saved form data entry')
 
@@ -42,9 +47,19 @@ class SavedFormDataEntryAdmin(admin.ModelAdmin):
 
     def queryset(self, request):
         queryset = super(SavedFormDataEntryAdmin, self).queryset(request)
-        queryset = queryset.select_related('form_entry', 'user',)
+        #queryset = queryset.select_related('form_entry', 'user',)
         return queryset
     get_queryset = queryset
 
+    def export_data(self, request, queryset):
+        """
+        Export data into XLS.
+        """
+        data_exporter = DataExporter(queryset)
+
+        return data_exporter.graceful_export()
+
+    export_data.short_description = _('Export data to CSV/XLS')
+
 
 admin.site.register(SavedFormDataEntry, SavedFormDataEntryAdmin)
