@@ -2,7 +2,7 @@ __title__ = 'fobi.contrib.themes.foundation5'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = 'Copyright (c) 2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('default_app_config', 'UID',)
+__all__ = ('default_app_config',)
 
 default_app_config = 'fobi.contrib.themes.foundation5.apps.Config'
 
